@@ -4,9 +4,7 @@ use strict;
 use warnings;
 use Tsk;
 require Exporter;
-use Data::Dumper;
 our @ISA = qw(Exporter);
-our $VERSION = '0.03';
 our @EXPORT = @Tsk::EXPORT;
 
 1;
